unit MMUtils;

interface

uses
    SysUtils, MMSystem;

//-----------------------------------------------------------------------------
//  mixerGetControlDetailsG[`FbN
function mixerGetControlDetailsError(const AResult: MMResult; const AFuncName: String = 'mixerGetControlDetails'): String;
//  mixerGetLineControlsG[`FbN
function mixerGetLineControlsError(const AResult: MMResult; const AFuncName: String = 'mixerGetLineControls'): String;
//  mixerGetLineInfoG[`FbN
function mixerGetLineInfoError(const AResult: MMResult; const AFuncName: String = 'mixerGetLineInfo'): String;
//  mixerOpenG[`FbN
function mixerOpenError(const AResult: MMResult; const AFuncName: String = 'mixerOpenError'): String;
//  mixerGetDevCapsG[`FbN
function mixerGetDevCapsError(const AResult: MMResult; const AFuncName: String = 'mixerGetDevCaps'): String;

implementation

//-----------------------------------------------------------------------------
//  mixerGetControlDetailsG[`FbN
function mixerGetControlDetailsError(const AResult: MMResult; const AFuncName: String = 'mixerGetControlDetails'): String;
begin
    Result := mixerGetLineControlsError(AResult, AFuncName);
end;

//-----------------------------------------------------------------------------
//  mixerGetLineControlsG[`FbN
function mixerGetLineControlsError(const AResult: MMResult; const AFuncName: String = 'mixerGetLineControls'): String;
begin
    case AResult of

    MMSYSERR_NOERROR: Result := '';
    MIXERR_INVALCONTROL:    Result := 'MIXERR_INVALCONTROL: The control reference is invalid.';
    else Result := mixerGetLineInfoError(AResult, AFuncName);

    end;
end;

//-----------------------------------------------------------------------------
//  mixerGetLineInfoG[`FbN
function mixerGetLineInfoError(const AResult: MMResult; const AFuncName: String = 'mixerGetLineInfo'): String;
begin
    case AResult of

    MMSYSERR_NOERROR: Result := '';

    MIXERR_INVALLINE:       Result := 'MIXERR_INVALLINE: The audio line reference is invalid.';
    MMSYSERR_BADDEVICEID:   Result := 'MMSYSERR_BADDEVICEID: The hmxobj parameter specifies an invalid device identifier.';
    MMSYSERR_INVALFLAG:     Result := 'MMSYSERR_INVALFLAG: One or more flags are invalid.';
    MMSYSERR_INVALHANDLE:   Result := 'MMSYSERR_INVALHANDLE: The hmxobj parameter specifies an invalid handle.';
    MMSYSERR_INVALPARAM:    Result := 'MMSYSERR_INVALPARAM: One or more parameters are invalid.';
    MMSYSERR_NODRIVER:      Result := 'MMSYSERR_NODRIVER: No mixer device is available for the object specified by hmxobj.';

    else Result := Format('Not %s Result', [AFuncName]);

    end;
end;

//-----------------------------------------------------------------------------
//  mixerOpenG[`FbN
function mixerOpenError(const AResult: MMResult; const AFuncName: String = 'mixerOpenError'): String;
begin
    case AResult of

    MMSYSERR_NOERROR: Result := '';

    MMSYSERR_ALLOCATED:     Result := 'MMSYSERR_ALLOCATED: The specified resource is already allocated by the maximum number of clients possible.';
    MMSYSERR_BADDEVICEID:   Result := 'MMSYSERR_BADDEVICEID: The uMxId parameter specifies an invalid device identifier.';
    MMSYSERR_INVALFLAG:     Result := 'MMSYSERR_INVALFLAG: One or more flags are invalid.';
    MMSYSERR_INVALHANDLE:   Result := 'MMSYSERR_INVALHANDLE: The uMxId parameter specifies an invalid handle.';
    MMSYSERR_INVALPARAM:    Result := 'MMSYSERR_INVALPARAM: One or more parameters are invalid.';
    MMSYSERR_NODRIVER:      Result := 'MMSYSERR_NODRIVER: No mixer device is available for the object specified by uMxId. Note that the location referenced by uMxId will also contain the value  - 1.';
    MMSYSERR_NOMEM:         Result := 'MMSYSERR_NOMEM: Unable to allocate resources.';

    else Result := Format('Not %s Result', [AFuncName]);

    end;
end;

//-----------------------------------------------------------------------------
//  mixerGetDevCapsG[`FbN
function mixerGetDevCapsError(const AResult: MMResult; const AFuncName: String = 'mixerGetDevCaps'): String;
begin
    case AResult of

    MMSYSERR_NOERROR: Result := '';

    MMSYSERR_BADDEVICEID:   Result := 'MMSYSERR_BADDEVICEID: The specified device identifier is out of range.';
    MMSYSERR_INVALHANDLE:   Result := 'MMSYSERR_INVALHANDLE: The mixer device handle is invalid.';
    MMSYSERR_INVALPARAM:    Result := 'MMSYSERR_INVALPARAM: One or more parameters are invalid.';

    else Result := Format('Not %s Result', [AFuncName]);

    end;
end;


end.
